Index: flashchips.h
===================================================================
--- flashchips.h
+++ flashchips.h
@@ -532,11 +532,12 @@
  * second byte is the device code,
  * third byte is a dummy byte.
  */
-#define SANYO_ID		0x62
+#define SANYO_ID		0x62    /* Sanyo */
 #define SANYO_LE25FW203A	0x1600
 #define SANYO_LE25FW403A	0x1100
 #define SANYO_LE25FW406		0x07	/* RES2 */
 #define SANYO_LE25FW418A	0x10	/* RES2 and some weird 1 byte RDID variant */
+#define SANYO_LE25FW406A	0x1A
 #define SANYO_LE25FU406B	0x1E	/* LE25FW418A without HD_READ mode option variant */
 #define SANYO_LE25FW806		0x26	/* RES2 and some weird 1 byte RDID variant */
 #define SANYO_LE25FW808		0x20	/* RES2 and some weird 1 byte RDID variant */
Index: flashchips.c
===================================================================
--- flashchips.c
+++ flashchips.c
@@ -9040,6 +9040,37 @@
 
 	{
 		.vendor		= "Sanyo",
+		.name		= "LE25FW406A",
+		.bustype	= BUS_SPI,
+		.manufacture_id	= SANYO_ID,
+		.model_id	= SANYO_LE25FW406A,
+		.total_size	= 512,
+		.page_size	= 256,
+		.feature_bits	= FEATURE_WRSR_WREN,
+		.tested		= TEST_OK_PREW,
+		.probe		= probe_spi_res2,
+		.probe_timing	= TIMING_ZERO,
+		.block_erasers	= {
+			{
+				.eraseblocks = { {4 * 1024, 128} },
+				.block_erase = spi_block_erase_d7,
+			},	{
+				.eraseblocks = { {64 * 1024, 8} },
+				.block_erase = spi_block_erase_d8,
+			},	{
+				.eraseblocks = { {512 * 1024, 1} },
+				.block_erase = spi_block_erase_c7,
+				}
+			},
+		.printlock	= spi_prettyprint_status_register_default_bp2,
+		.unlock		= spi_disable_blockprotect,
+		.write		= spi_chip_write_256,
+		.read		= spi_chip_read,
+		.voltage	= {2700, 3600},
+	},
+
+	{
+		.vendor		= "Sanyo",
 		.name		= "LE25FU406B",
 		.bustype	= BUS_SPI,
 		.manufacture_id	= SANYO_ID,
